@@ -198,7 +198,7 @@ class Image(object):
 
         if deg == "auto":
             if self._orig_format == "JPEG":
-                exif = self.img._getexif() or dict
+                exif = self.img._getexif() or dict()
                 deg = _orientation_to_rotation.get(exif.get(274, 0), 0)
             else:
                 deg = 0
